pymop - Multi-Objective Optimization Problems
==================================

This framework provides a collection of test problems in Python. The main features are:

- Most important multi-objective test function is one place
- Vectorized evaluation by using numpy matrices (no for loops)
- Gradients and Hessian matrices are available through automatic differentiation
- Easily new problems can be created using custom classes or functions


Here, you can find a detailed documentation and information about the framework:
https://www.egr.msu.edu/coinlab/blankjul/pymop/


.. image:: https://gitlab.msu.edu/blankjul/pymop/badges/master/pipeline.svg
   :alt: pipeline status
   :target: https://gitlab.msu.edu/blankjul/pymop/commits/master



Problems
==================================

In this package single- as well as multi-objective test problems are
included:


-  Single-Objective:

   -  Ackley
   -  Cantilevered Beam
   -  Griewank
   -  Himmelblau
   -  Knapsack
   -  Pressure Vessel
   -  Schwefel
   -  Sphere
   -  Zakharov
   -  G

-  Multi-Objective:

   -  ZDT 1-6 
   -  DTLZ 1-7 
   -  CDTLZ 
   -  CTP 
   -  Carside Impact
   -  BNH
   -  Kursawe
   -  OSY
   -  TNK
   -  Truss 2D
   -  Welded Beam
